% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/automaticCOTANObjectCreation.R
\name{COTANObjectCreation}
\alias{COTANObjectCreation}
\alias{proceedToCoex,COTAN-method}
\alias{proceedToCoex}
\alias{automaticCOTANObjectCreation}
\title{Automatic \code{COTAN} shortcuts}
\usage{
\S4method{proceedToCoex}{COTAN}(
  objCOTAN,
  calcCoex = TRUE,
  cores = 1L,
  saveObj = TRUE,
  outDir = "."
)

automaticCOTANObjectCreation(
  raw,
  GEO,
  sequencingMethod,
  sampleCondition,
  calcCoex = TRUE,
  cores = 1L,
  saveObj = TRUE,
  outDir = "."
)
}
\arguments{
\item{objCOTAN}{a newly created \code{COTAN} object}

\item{calcCoex}{a Boolean to determine whether to calculate the genes' \code{COEX}
or stop just before at the \code{\link[=estimateDispersionBisection]{estimateDispersionBisection()}} step}

\item{cores}{number of cores to be used}

\item{saveObj}{Boolean flag; when \code{TRUE} saves intermediate analyses and
plots to file}

\item{outDir}{an existing directory for the analysis output.}

\item{raw}{a matrix or dataframe with the raw counts}

\item{GEO}{a code reporting the GEO identification or other specific dataset
code}

\item{sequencingMethod}{a string reporting the method used for the sequencing}

\item{sampleCondition}{a string reporting the specific sample condition or
time point.}
}
\value{
\code{proceedToCoex()} returns the updated \code{COTAN} object with genes'
\code{COEX} calculated. If asked to, it will also store the object, along all
relevant clean-plots, in the output directory.

\code{automaticCOTANObjectCreation()} returns the new \code{COTAN} object with
genes' \code{COEX} calculated. When asked, it will also store the object, along
all relevant clean-plots, in the output directory.
}
\description{
These functions take (or create) a \code{COTAN} object and run all
the necessary steps until the genes' \code{COEX} matrix is calculated.

takes a newly created \code{COTAN} object (or the result of a call to
\code{\link[=dropGenesCells]{dropGenesCells()}}) and applies all steps until the genes' \code{COEX} matrix is
stored in the object
}
\details{
\code{proceedToCoex()} takes a newly created \code{COTAN} object (or the
result of a call to \code{dropGenesCells()}) and runs \code{\link[=calculateCoex]{calculateCoex()}}

\code{automaticCOTANObjectCreation()} takes a raw dataset, creates and
initializes a \code{COTAN} objects and runs proceedToCoex()
}
\examples{
data("test.dataset")

## In case one needs to run more steps to clean the datatset the following
## might apply
##
## objCOTAN <- COTAN(raw = test.dataset)
## objCOTAN <- initializeMetaDataset(objCOTAN,
##                                   GEO = "test",
##                                   sequencingMethod = "artificial",
##                                   sampleCondition = "test dataset")
## # in case the genes' `COEX` is not needed it can be skipped
## # (e.g. for [cellsUniformClustering()])
## objCOTAN <- proceedToCoex(objCOTAN, calcCoex = FALSE,
##                           cores = 12, saveObj = FALSE)


## Otherwise it is possible to run all at once.
objCOTAN <- automaticCOTANObjectCreation(
  raw = test.dataset,
  GEO = "code",
  sequencingMethod = "10X",
  sampleCondition = "mouse_dataset",
  calcCoex = TRUE,
  saveObj = FALSE,
  outDir = tempdir(),
  cores = 12)

}
