% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/establishGenesClusters.R
\name{GenesCoexSpace}
\alias{GenesCoexSpace}
\alias{genesCoexSpace}
\alias{establishGenesClusters}
\title{Local Differentiation Index}
\usage{
genesCoexSpace(objCOTAN, primaryMarkers, numGenesPerMarker = 25L)

establishGenesClusters(
  objCOTAN,
  groupMarkers,
  numGenesPerMarker = 25L,
  kCuts = 6L,
  distance = "cosine",
  hclustMethod = "ward.D2"
)
}
\arguments{
\item{objCOTAN}{a \code{COTAN} object}

\item{primaryMarkers}{A vector of primary marker names.}

\item{numGenesPerMarker}{the number of correlated genes to keep as other
markers (default 25)}

\item{groupMarkers}{a named \code{list} with an element for each group comprised
of one or more marker genes}

\item{kCuts}{the number of estimated \emph{cluster} (this defines the height for
the tree cut)}

\item{distance}{type of distance to use (default is \code{"cosine"}, \code{"euclidean"}
and the others from \code{\link[parallelDist:parDist]{parallelDist::parDist()}} are also available)}

\item{hclustMethod}{default is "ward.D2" but can be any method defined by
\code{\link[stats:hclust]{stats::hclust()}} function}
}
\value{
\code{genesCoexSpace()} returns a \code{list} with:
\itemize{
\item \code{"SecondaryMarkers"} a named \code{list} that for each secondary marker,
gives the \code{list} of primary markers that selected for it
\item \code{"GCS"} the \code{COEX} \code{data.frame}
\item \code{"rankGenes"} a \code{data.frame} with the rank of each gene according to its
\emph{p-value}
}

\code{establishGenesClusters()} a \code{list} of:
\itemize{
\item \code{"g.space"} the genes' \code{COEX} space \code{data.frame}
\item \code{"plot.eig"} the eigenvalues plot
\item \code{"pca_clusters"} the \emph{pca} components \code{data.frame}
\item \code{"tree_plot"} the tree plot for the genes' \code{COEX} space
}
}
\description{
To make the \code{GDI} more specific, it may be desirable to restrict
the set of genes against which \code{GDI} is computed to a selected subset, with
the recommendation to include a consistent fraction of cell-identity genes,
and possibly focusing on markers specific for the biological question of
interest (for instance neural cortex layering markers). In this case we
denote it as \emph{Local Differentiation Index} (LDI) relative to the selected
subset.
}
\details{
\code{genesCoexSpace()} calculates genes groups based on the primary
markers and uses them to prepare the genes' \code{COEX} space \code{data.frame}.

\code{establishGenesClusters()} perform the genes' clustering based on a
pool of gene markers, using the genes' \code{COEX} space
}
\examples{
data("test.dataset")
objCOTAN <- COTAN(raw = test.dataset)
objCOTAN <- proceedToCoex(objCOTAN, cores = 12, saveObj = FALSE)

markers <- getGenes(objCOTAN)[sample(getNumGenes(objCOTAN), 10)]
GCS <- genesCoexSpace(objCOTAN, primaryMarkers = markers,
                      numGenesPerMarker = 15)

groupMarkers <- list(G1 = c("g-000010", "g-000020", "g-000030"),
                     G2 = c("g-000300", "g-000330"),
                     G3 = c("g-000510", "g-000530", "g-000550",
                            "g-000570", "g-000590"))

resList <-  establishGenesClusters(objCOTAN, groupMarkers = groupMarkers,
                                   numGenesPerMarker = 11)

}
