% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/numericUtilities.R
\name{LegacyFastSymmMatrix}
\alias{LegacyFastSymmMatrix}
\alias{vec2mat_rfast}
\alias{mat2vec_rfast}
\title{Handle symmetric matrix <-> vector conversions}
\usage{
vec2mat_rfast(x, genes = "all")

mat2vec_rfast(mat)
}
\arguments{
\item{x}{a \code{list} formed by two arrays: \code{genes} with the unique gene names
and \code{values} with all the values.}

\item{genes}{an array with all wanted genes or the string \code{"all"}. When equal
to \code{"all"} (the default), it recreates the entire matrix.}

\item{mat}{a square (possibly symmetric) matrix with all genes as row and
column names.}
}
\value{
\code{vec2mat_rfast} returns the reconstructed symmetric matrix

\code{mat2vec_rfast} a \code{list} formed by two arrays:
\itemize{
\item \code{genes} with the unique gene names,
\item \code{values} with all the values.
}
}
\description{
Converts a symmetric matrix into a compacted symmetric matrix
and vice-versa.
}
\details{
This is a legacy function related to old \code{scCOTAN} objects. Use the
more appropriate \code{Matrix::dspMatrix} type for similar functionality.

\code{mat2vec_rfast}will forcibly make its argument symmetric.
}
\examples{
v <- list("genes" = paste0("gene_", c(1:9)), "values" = c(1:45))

M <- vec2mat_rfast(v)
all.equal(rownames(M), v[["genes"]])
all.equal(colnames(M), v[["genes"]])

genes <- paste0("gene_", sample.int(ncol(M), 3))

m <- vec2mat_rfast(v, genes)
all.equal(rownames(m), v[["genes"]])
all.equal(colnames(m), genes)

v2 <- mat2vec_rfast(M)
all.equal(v, v2)

}
